/* 	libchenabler - API definition of the call history service
 *
 *	Authors: JIANG Dan <dan.jiang@orange-ftgroup.com> 
 *	
 *	This software and associated documentation files (the "Software") 
 *	are copyright (C) 2005 LiPS Linux Phone Standards Forum [FranceTelecom] 
 *	All Rights Reserved. 
 *
 *	A copyright license is hereby granted for redistribution and use of 
 *	the Software in source and binary forms, with or without modification, 
 *	provided that the following conditions are met: 
 *	- Redistributions of source code must retain the above copyright notice, 
 *	this copyright license and the following disclaimer. 
 * - Redistributions in binary form must reproduce the above copyright 
 *	notice, this copyright license and the following disclaimer in the 
 *	documentation and/or other materials provided with the distribution. 
 *	- Neither the name of LiPS  nor the names of its Members may be used 
 *	to endorse or promote products derived from the Software without 
 *	specific prior written permission. 
 *
 *	A patent license for any Necessary Claims owned by Members of LiPS Forum 
 *	to make, have made, use, import, offer to sell, lease and sell or otherwise 
 *	distribute any implementation compliant with the any specification adopted 
 *	by the LiPS Forumcan be obtained from the respective Members on reasonable 
 *	and non-discriminatory terms and conditions and under reciprocity, as 
 *	regulated in more detail in the Internal Policy of the LiPS Forum. 
 *
 *	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER, ITS MEMBERS AND CONTRIBUTORS 
 *	"AS IS", AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 *	THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
 *	AND NON-INFRINGEMENT ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER, 
 *	ITS MEMBERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *	SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 *	PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 *	OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 *	WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *	ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 *	POSSIBILITY OF SUCH DAMAGE. 
 */

/**
 *@file Environment of the Voice Call History interface
 */

#ifndef __LIPS_VOCH_CALLHISTORY_H
#define __LIPS_VOCH_CALLHISTORY_H

#include "vochtype.h"
#include "vocherror.h"

#ifdef __cplusplus
extern "C"
{
#endif                          /* __cplusplus */

/**
 *@brief VOC History structure
 */
  typedef struct _voch_callhistory_t voch_callhistory_t;


/**
 *@brief voch_callhistory_t relative functions.
 */

/**
 *@brief	add a duplicate field of field template ftid to history
 *@param	history	pointer to the history instance whose field will be add
 *@param	ftid			field template id
 *@param	fid				returned id for the newly added field
 */
  voch_err_t voch_callhistory_add_field (voch_callhistory_t *history,
                                         voch_ftid_t ftid, voch_fid_t *fid);

/**
 *@brief	a general setting function. setting a value to a field of a history
 *@param	history	pointer to the history instance whose field will be set
 *@param	fid				identifier to the field which will be set a value
 *@param	value			pointer to a field value which will be assigned to the field. A copy of the value will
 *									be assigned to the field and the value pointer should be freed by app later.
 */
  voch_err_t voch_callhistory_set_field (voch_callhistory_t *history,
                                         voch_fid_t fid, const void *value);

/**
 *@brief	a general getting function. getting a value from a field of a history
 *@param	hisotory pointer to the history instance whose field will be queried
 *@param	fid				identifier to the field whose value will be get
 *@param	value			a copy of the field value is returned and app should free it later
 */
  voch_err_t voch_callhistory_get_field (voch_callhistory_t *history,
                                         voch_fid_t fid, void **value);

/**
 *@brief	remove from a history all fields corresponding to a customized field template.
 *@param	history pointer to the history instance
 *@param	fid			field id to be removed
 */
  voch_err_t voch_callhistory_rm_field (voch_callhistory_t *history,
                                        voch_fid_t fid);


/**
 *@brief Print each item in the history
 *
 *@param history	the structure to store the voc history record
 *
 *@return  
 */
  void voch_callhistory_print (const voch_callhistory_t *history);

/**
 *@brief get the cid from the history
 *
 *@param history	the structure to store the voc history record
 *@param cid 	the address of the pointer to which stores the cid value
 *@return  
 */
  voch_err_t voch_callhistory_get_cid (const voch_callhistory_t *history,
                                       voch_cid_t *cid);

/**
 *@brief get the type from the history
 *
 *@param history	the structure to store the voc history record
 *@param type 	the address of the pointer to which stores the type value
 *@return  
 */
  voch_err_t voch_callhistory_get_type (const voch_callhistory_t *history,
                                        voch_call_type_t **type);

/**
 *@brief get the date from the history
 *
 *@param history	the structure to store the voc history record
 *@param type 	the address of the pointer to which stores the date value
 *@return  
 */
  voch_err_t voch_callhistory_get_date (const voch_callhistory_t *history,
                                        time_t **date);


/**
 *@brief get the duration from the history
 *
 *@param history	the structure to store the voc history record
 *@param type 	the pointer to which stores the duration value
 *@return  
 */
  voch_err_t voch_callhistory_get_duration (const voch_callhistory_t *
                                            history, time_t **duration);


/**
 *@brief get the phonenumber from the history
 *
 *@param history	the structure to store the voc history record
 *@param type 	the address of the pointer to which stores the phonenumber value
 *@return  
 */
  voch_err_t voch_callhistory_get_phonenumber (const voch_callhistory_t *
                                               history, char **phonenumber);



 /**
 *@brief set the value of date in the history
 *
 *@param history	the structure to store the voc history record
 *@param date 	the date value
 *@return  
 */
  voch_err_t voch_callhistory_set_date (voch_callhistory_t *history,
                                        time_t date);

/**
 *@brief set the value of duration in the history
 *
 *@param history	the structure to store the voc history record
 *@param type 	the duration value
 *@return  
 */
  voch_err_t voch_callhistory_set_duration (voch_callhistory_t *history,
                                            time_t duration);

/**
 *@brief set the value of phonenumber in the history
 *
 *@param history	the structure to store the voc history record
 *@param type 	the phonenumber value
 *@return  
 */
  voch_err_t voch_callhistory_set_phonenumber (voch_callhistory_t *history,
                                               char *phonenumber);


/**
 *@brief set the value of duration in the history
 *
 *@param history	the structure to store the voc history record
 *@param type 	the type value
 *@return  
 */
  voch_err_t voch_callhistory_set_type (voch_callhistory_t *history,
                                        voch_call_type_t type);

/**
 *@brief free the memory of the history stucture
 *
 *@param history	the structure to store the voc history record
 *@return  
 */
  voch_err_t voch_callhistory_free (voch_callhistory_t *history);


/**
 *@brief	list field ids which are contained in the history instance
 *@param fids			voch_TEMPLATE_ID_INVALID terminated fid array, allocated by enabler and freed by app.
 *@param flag			if set to 1, list all field ids; if set to 0, only list those id of fields which are
 *									not empty
 */
//voch_err_t voch_list_fields (voch_callhistory_t *history, uint32_t flag,voch_fid_t **fids);



#ifdef __cplusplus
}
#endif                          /* __cplusplus */
#endif                          /* __LIPS_VOCH_CALLHISTORY_H */

