/* 	libchenabler - API definition of the call history service
 *
 *	Authors: JIANG Dan <dan.jiang@orange-ftgroup.com> 
 *	
 *	This software and associated documentation files (the "Software") 
 *	are copyright (C) 2005 LiPS Linux Phone Standards Forum [FranceTelecom] 
 *	All Rights Reserved. 
 *
 *	A copyright license is hereby granted for redistribution and use of 
 *	the Software in source and binary forms, with or without modification, 
 *	provided that the following conditions are met: 
 *	- Redistributions of source code must retain the above copyright notice, 
 *	this copyright license and the following disclaimer. 
 * - Redistributions in binary form must reproduce the above copyright 
 *	notice, this copyright license and the following disclaimer in the 
 *	documentation and/or other materials provided with the distribution. 
 *	- Neither the name of LiPS  nor the names of its Members may be used 
 *	to endorse or promote products derived from the Software without 
 *	specific prior written permission. 
 *
 *	A patent license for any Necessary Claims owned by Members of LiPS Forum 
 *	to make, have made, use, import, offer to sell, lease and sell or otherwise 
 *	distribute any implementation compliant with the any specification adopted 
 *	by the LiPS Forumcan be obtained from the respective Members on reasonable 
 *	and non-discriminatory terms and conditions and under reciprocity, as 
 *	regulated in more detail in the Internal Policy of the LiPS Forum. 
 *
 *	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER, ITS MEMBERS AND CONTRIBUTORS 
 *	"AS IS", AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 *	THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE 
 *	AND NON-INFRINGEMENT ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER, 
 *	ITS MEMBERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *	SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 *	PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 *	OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 *	WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 *	ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 *	POSSIBILITY OF SUCH DAMAGE. 
 */
/**
 *@file API definition of the Voice Call History - Template
 */

#ifndef __LIPS_VOCH_TEMPLATE_H
#define __LIPS_VOCH_TEMPLATE_H

#include "vochtype.h"
#include "vocherror.h"

#ifdef __cplusplus
extern "C"
{
#endif                          /* __cplusplus */

#define         VOC_FIELD_TYPE_BOOLEAN                   0
#define         VOC_FIELD_TYPE_INTEGER                   1
#define         VOC_FIELD_TYPE_FLOAT                     2
#define         VOC_FIELD_TYPE_STRING                    3
#define         VOC_FIELD_TYPE_DATE                      4
#define         VOC_FIELD_TYPE_BINARY                    5

#define         VOC_FIELD_ID_INVALID                     0
#define         VOC_FIELD_ID_START                       1
#define         VOC_FIELD_ID_USER_DEFINED                10000
#define         VOC_FIELD_ID_DUP_RANGE                   1000

#define         VOC_ATTR_NONE                                                    0
#define         VOC_ATTR_MANDATORY                                       (0x1 << 0)
#define         VOC_ATTR_STANDARD                                        (0x1 << 1)
#define         VOC_ATTR_PRIMARY                                         (0x1 << 2)

/**
 *@brief a set of getting functions. getting meta info about the field template
 */
  voch_err_t voc_field_template_get_label (voch_ftid_t id, char **label);
  voch_err_t voc_field_template_get_name (voch_ftid_t id, char **name);
  voch_err_t voc_field_template_get_type (voch_ftid_t id, int *type);
  voch_err_t voc_field_template_is_mandatory (voch_ftid_t id,
                                              uint32_t *mandatory);
  voch_err_t voc_field_template_is_standard (voch_ftid_t id,
                                             uint32_t *standard);
  voch_err_t voc_field_template_get_max_size (voch_ftid_t id, uint32_t *size);

/**
 *@brief       add a custom and optional field template to history record
 *@param       sid                             session id of the history record
 *@param       ftid                    returned id for the newly added field template
 *@param       label                   print label of the field
 *@param       name                    name of field
 *@param       type                    type of field value
 *@param       max_size        maximum storage size of the field value
 */
  voch_err_t voc_field_template_create (voch_sid_t *sid,
                                        voch_ftid_t *ftid,
                                        const char *label,
                                        const char *name,
                                        uint32_t type, uint32_t max_size);

/**
 *@brief       delete a custom and optional field from addressbook
 *@param       sid                             session id of the history record
 *@param       ftid                    id of the field template to be deleted
 */
  voch_err_t voc_field_template_del (voch_sid_t *sid, voch_ftid_t ftid);

/**
 *@brief       get the field template id from the field id
 *@param       fid                             a field id
 *@param       ftid                    return id of the field template
 */
  voch_err_t voc_field_template_get_id (voch_fid_t fid, voch_ftid_t *ftid);

#ifdef __cplusplus
}
#endif                          /* __cplusplus */

#endif                          /* __LIPS_VOCH_TEMPLATE_H */

/* 
vi:ts=2:nowrap:ai:expandtab
*/

